@@ -8,7 +8,7 @@ use base qw(RDF::RDFa::Parser::Profile);
 use strict;
 use 5.008;
 
-our $VERSION = '1.09_05';
+our $VERSION = '1.09_06';
 
 BEGIN
 {
@@ -66,7 +66,7 @@ sub new
 			foreach (@line)
 			{
 				my @fields = split /\s+/;
-				push @$self, \@fields;
+				push @$self, [@fields, 1];
 			}
 		}
 	}
